@@ -1,10 +1,10 @@
 from typing import Dict, List
 
-from kognic.io.model.base_serializer import BaseSerializer
 from kognic.io.model.ego.imu_data import IMUData
+from kognic.io.model.input.abstract.base_input import BaseInput
 
 
-class BaseInputWithIMUData(BaseSerializer):
+class BaseInputWithIMUData(BaseInput):
     """
     Base class for any input that has IMU data.
     """
