@@ -8,3 +8,8 @@ class Frame(SequenceFrame):
     images: List[Image] = []
     video_frames: List[VideoFrame] = []
     metadata: Mapping[str, Union[int, float, str, bool]] = {}
+
+    @property
+    def resources(self) -> Mapping[str, Image]:
+        # Video is not included as of 2022-10; currently unused and unsupported.
+        return {i.resource_id: i for i in self.images}
