@@ -1,6 +1,6 @@
-from typing import Dict, List
+from typing import Mapping
 
-from kognic.io.model.base_serializer import BaseSerializer
+from kognic.io.model import PointCloud
 from kognic.io.model.input.abstract import BaseInputWithIMUData
 from kognic.io.model.input.lidars.frame import Frame
 from kognic.io.model.input.metadata.metadata import AllowedMetaData
@@ -9,4 +9,8 @@ from kognic.io.model.input.metadata.metadata import AllowedMetaData
 class Lidars(BaseInputWithIMUData):
     external_id: str
     frame: Frame
-    metadata: AllowedMetaData
+    metadata: AllowedMetaData = dict()
+
+    @property
+    def resources(self) -> Mapping[str, PointCloud]:
+        return self.frame.resources
