@@ -1,5 +1,7 @@
 from typing import Optional
 
+from pydantic import validator
+
 from kognic.io.model.base_serializer import BaseSerializer
 from kognic.io.model.input.resources.resource import Resource
 
@@ -12,7 +14,11 @@ class ImageMetadata(BaseSerializer):
 
 
 class Image(Resource):
-    filename: str
-    resource_id: Optional[str] = None
     sensor_name: str = camera_sensor_default
     metadata: Optional[ImageMetadata] = None
+
+    @validator('file_data', pre=True)
+    def cannot_be_pointcloud(cls, value):
+        if not value.format.is_image:
+            raise ValueError(f"Invalid format for image data: {value.format}")
+        return value
